@@ -170,7 +170,7 @@ class NEAL3Way(object):
     
     """
     
-    def __init__(self, bases, associate, turnon="all"):
+    def __init__(self, bases, associate, turnon="all", twotest=None):
         # bases = {"units": ["animal", "mammal", "bird", "canary"],
         #          "relations": [ ["canary", "bird"], ["bird", "animal"], ["mammal", "animal"] ]}
         # associate = {"properties": ["food", "fur", "flying", "yellow"], # properties to be associated between base units and its relations
@@ -182,7 +182,7 @@ class NEAL3Way(object):
         #
         self.__create_datastructures(bases, associate)
         self.__create_network()
-        self.__choose_applicable_test( turnon )
+        self.__choose_applicable_test( turnon, twotest )
         #
         neal.nealApplyProjections()
         sim.run(self.simTime)
@@ -232,20 +232,34 @@ class NEAL3Way(object):
         self.neural3assoc_topology.createAssociationTopology( self.propdata, self.reldata )
         self.neural3assoc_topology.addAssociations( self.assocdata )
         
-    def __choose_applicable_test(self, turnon):
+    def __choose_applicable_test(self, turnon, twotest=None):
         """If ``turnon = "all"`` then all the cell assemblies for each subject (base), object (property) and relation (predicate) is activated.
         On the other hand, if ``turnon = [<subject-name>, <predicate-name>, <object-name>]`` only cell assemblies for these are trigerred."""
         if turnon=="all":
             self.simTime = self.neural3assoc_topology.createUnitTests() + 100
-        else:
-            baseNum = self.basedata.getUnitNumber( turnon[0] ) # base or subject
-            probNum = self.propdata.getUnitNumber( turnon[1] ) # property or object
-            try:
-                relNum = self.reldata.getUnitNumber( turnon[2] )# relation or predicate
-            except:
-                relNum = -1 # cell assembly for relation is not activated
+            self.test_metadata = [turnon, twotest]
+        elif (turnon!="all" and twotest=="prime"):
+            baseNum = self.__check_and_returnUnitNumber( self.basedata, turnon, 0 ) # base or subject
+            probNum = self.__check_and_returnUnitNumber( self.propdata, turnon, 1 ) # property or object
+            relNum = self.__check_and_returnUnitNumber( self.reldata, turnon, 2 ) # relation or predicate
             self.neural3assoc_topology.createTwoPrimeTest( baseNum, probNum, relNum )
             self.simTime = 200.0
+            self.test_metadata = [None, "prime"]
+        elif (turnon!="all" and twotest is None):
+            baseNum = self.__check_and_returnUnitNumber( self.basedata, turnon, 0 ) # base or subject
+            probNum = self.__check_and_returnUnitNumber( self.propdata, turnon, 1 ) # property or object
+            relNum = self.__check_and_returnUnitNumber( self.reldata, turnon, 2 ) # relation or predicate
+            self.neural3assoc_topology.createTwoTest( baseNum, probNum, relNum )
+            self.simTime = 200.0
+            self.test_metadata = [None, None]
+    
+    # Private function for returning a unit number for respective structured data
+    def __check_and_returnUnitNumber(self, strdata, turnon, indx):
+        try:
+            someNum = strdata.getUnitNumber( turnon[indx] )
+        except:
+            someNum = -1 # cell assembly will not be activated
+        return someNum
     
     # Private function for getting Neo object for all the created cell assemblies.
     def __getdata(self):
@@ -311,47 +325,57 @@ class NEAL3Way(object):
             return dataname.strip("data") # basedata -> base
     
     # Private function for each subplot in :py:meth:`.plot_all`
-    def __subplot_all(self, dataname, subplotobject, clrs):
+    def __subplot_all(self, dataname, colorname, subplotobject):
         """For a given ``subplotobject`` this function returns matplotlib's `eventplot <https://matplotlib.org/3.1.1/api/_as_gen/matplotlib.pyplot.eventplot.html>`_
         for spiketrains from all the cell units of all the cell assemblies for a given data structure (assigned by the ``dataname`` argument)."""
         legpatches = []
         data = getattr(self, dataname) # "basedata" or "propdata" or "reldata"
+        clrs = self.__generate_compatible_subplot_colors(colorname, data.numberUnits)
         for unit in data.units:
             i = data.getUnitNumber(unit)
-            subplotobject.eventplot( self.results[ self.__get_resultskey(dataname) ][ unit ],
-                                     color = clrs(1.0 - (i*0.1) ) )
-            legpatches.append( mpatches.Patch(color=clrs( 1.0-(i*0.1) ), label=unit) )
+            if self.test_metadata[0]=="all":
+                subplotobject.eventplot( self.results[ self.__get_resultskey(dataname) ][ unit ],
+                                         color = clrs(1.0 - (i*0.1) ) )
+                legpatches.append( mpatches.Patch(color=clrs( 1.0-(i*0.1) ), label=unit) )
+            else:
+                subplotobject.eventplot( self.results[ self.__get_resultskey(dataname) ][ unit ],
+                                         color = clrs[i] )
+                legpatches.append( mpatches.Patch(color=clrs[i], label=unit) )
         subplotobject.legend( handles=legpatches, shadow=True )
+        
+    # Private function for returning color map (a tuple) or list of colors
+    def __generate_compatible_subplot_colors(self, colorname, numberUnits):
+        if self.test_metadata[0]=="all": # returns a tuple
+            return cm.get_cmap(colorname, 12) # "Reds", "Greens", "Blues"
+        else:
+            return ['C{}'.format(i) for i in range(numberUnits)]
     
     def plot_all(self):
         """Plot of three subplots such that each subplot (invoking :py:meth:`.__subplot_all`) is the matplotlib's `eventplot <https://matplotlib.org/3.1.1/api/_as_gen/matplotlib.pyplot.eventplot.html>`_
         of `SpikeTrain <https://neo.readthedocs.io/en/stable/api_reference.html#neo.core.SpikeTrain>`_ such that
         
-        +---------+------------------------------------------------------------+-----------+
-        | subplot | spike trains for all cell units in all cell assemblies for | color map |
-        +=========+============================================================+===========+
-        | top     | subject (a.k.a base in ``basedata``)                       | Reds      |
-        +---------+------------------------------------------------------------+-----------+
-        | middle  | predicate (a.k.a relation in ``reldata``)                  | Greens    |
-        +---------+------------------------------------------------------------+-----------+
-        | bottom  | object (a.k.a property in ``propdata``)                    | Blues     |
-        +---------+------------------------------------------------------------+-----------+
+        +---------+------------------------------------------------------------+----------------------------------+
+        | subplot | spike trains for all cell units in all cell assemblies for | color map for ``turnon = "all"`` |
+        +=========+============================================================+==================================+
+        | top     | subject (a.k.a base in ``basedata``)                       | Reds                             |
+        +---------+------------------------------------------------------------+----------------------------------+
+        | middle  | predicate (a.k.a relation in ``reldata``)                  | Greens                           |
+        +---------+------------------------------------------------------------+----------------------------------+
+        | bottom  | object (a.k.a property in ``propdata``)                    | Blues                            |
+        +---------+------------------------------------------------------------+----------------------------------+
         
         """
         fig, ((sp1),
               (sp2),
               (sp3)) = plt.subplots(3,1, sharex=True)
-        # Red color for subject, i.e. base Therefore its spectrum is used here
-        clrs = cm.get_cmap('Reds', 12)
-        self.__subplot_all("basedata", sp1, clrs)
+        # If turnon is "all" Red color for subject, i.e. base Therefore its spectrum is used here
+        self.__subplot_all("basedata", "Reds", sp1)
         #
-        # Green color for predicate, i.e. relation
-        clrs = cm.get_cmap('Greens', 12)
-        self.__subplot_all("reldata", sp2, clrs)
+        # If turnon is "all" Green color for predicate, i.e. relation
+        self.__subplot_all("reldata", "Greens", sp2)
         #
-        # Blue color for object, i.e. property
-        clrs = cm.get_cmap('Blues', 12)
-        self.__subplot_all("propdata", sp3, clrs)
+        # If turnon is "all" Blue color for object, i.e. property
+        self.__subplot_all("propdata", "Blues", sp3)
         #
         sp1.title.set_text("Subject (base)")
         sp2.title.set_text("Predicate (relation)")
